aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/utils/logging/LoggerRegistry.h
diff options
context:
space:
mode:
Diffstat (limited to 'arm_compute/core/utils/logging/LoggerRegistry.h')
-rw-r--r--arm_compute/core/utils/logging/LoggerRegistry.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/arm_compute/core/utils/logging/LoggerRegistry.h b/arm_compute/core/utils/logging/LoggerRegistry.h
index d861476fea..d3c691139e 100644
--- a/arm_compute/core/utils/logging/LoggerRegistry.h
+++ b/arm_compute/core/utils/logging/LoggerRegistry.h
@@ -51,10 +51,11 @@ public:
* @note Some names are reserved e.g. [CORE, RUNTIME, GRAPH]
*
* @param[in] name Logger's name
* @param[in] log_level Logger's log level
* @param[in] printers Printers to attach to the system loggers
*/
- void create_logger(const std::string &name, LogLevel log_level, std::vector<std::shared_ptr<Printer>> printers = {});
+ void create_logger(const std::string &name, LogLevel log_level = LogLevel::INFO,
+ std::vector<std::shared_ptr<Printer>> printers = { std::make_shared<StdPrinter>() });
/** Remove a logger
*
* @param name Logger's name
@@ -69,10 +70,11 @@ public:
std::shared_ptr<Logger> logger(const std::string &name);
/** Creates reserved library loggers
*
* @param[in] log_level Logger's log level
* @param[in] printers Printers to attach to the system loggers
*/
- void create_reserved_loggers(LogLevel log_level, std::vector<std::shared_ptr<Printer>> printers = {});
+ void create_reserved_loggers(LogLevel log_level = LogLevel::INFO,
+ std::vector<std::shared_ptr<Printer>> printers = { std::make_shared<StdPrinter>() });
private:
/** Default constructor */
@@ -51,10 +51,11 @@ public:
*
* @param[in] name Logger's name
- * @param[in] log_level Logger's log level
- * @param[in] printers Printers to attach to the system loggers
+ * @param[in] log_level Logger's log level. Defaults to @ref LogLevel::INFO
+ * @param[in] printers Printers to attach to the system loggers. Defaults with a @ref StdPrinter.
*/
@@ -69,10 +70,11 @@ public:
/** Creates reserved library loggers
*
- * @param[in] log_level Logger's log level
- * @param[in] printers Printers to attach to the system loggers
+ * @param[in] log_level (Optional) Logger's log level. Defaults to @ref LogLevel::INFO
+ * @param[in] printers (Optional) Printers to attach to the system loggers. Defaults with a @ref StdPrinter.
*/